@@ -78,7 +78,7 @@ class HonParameterEnum(HonParameter):
 
     @property
     def values(self):
-        return [str(value for value in self._values]
+        return [str(value) for value in self._values]
 
     @property
     def value(self):
@@ -86,7 +86,7 @@ class HonParameterEnum(HonParameter):
 
     @value.setter
     def value(self, value):
-        if value in self._values:
+        if value in self.values:
             self._value = self._value
         else:
             raise ValueError(f"values {self._value}")
